@@ -1,27 +1,24 @@
 # -*- coding: utf-8 -*-
+# Copyright (C) 2012 Anaconda, Inc
+# SPDX-License-Identifier: BSD-3-Clause
 from __future__ import absolute_import, division, print_function, unicode_literals
 
-from itertools import chain
 from logging import getLogger
 
+from itertools import chain
+
 from .package_cache_data import PackageCacheData
-from .prefix_data import PrefixData, linked_data
+from .prefix_data import PrefixData
 from .subdir_data import SubdirData, make_feature_record
 from .._vendor.boltons.setutils import IndexedSet
+from .._vendor.toolz import concat, concatv, groupby
 from ..base.context import context
-from ..common.compat import iteritems, itervalues
-from ..common.io import ThreadLimitedThreadPoolExecutor, as_completed, time_recorder
-from ..exceptions import OperationNotAllowed
+from ..common.compat import itervalues
+from ..common.io import ThreadLimitedThreadPoolExecutor, as_completed, dashlist, time_recorder
+from ..exceptions import ChannelNotAllowed, InvalidSpec
 from ..models.channel import Channel, all_channel_urls
-from ..models.dist import Dist
 from ..models.match_spec import MatchSpec
 from ..models.records import EMPTY_LINK, PackageCacheRecord, PrefixRecord
-from ..resolve import dashlist
-
-try:
-    from cytoolz.itertoolz import concat, concatv, groupby, take
-except ImportError:  # pragma: no cover
-    from .._vendor.toolz.itertoolz import concat, concatv, groupby, take  # NOQA
 
 log = getLogger(__name__)
 
@@ -34,11 +31,7 @@ def check_whitelist(channel_urls):
         for url in channel_urls:
             these_urls = Channel(url).base_urls
             if not all(this_url in whitelist_channel_urls for this_url in these_urls):
-                bad_channel = Channel(url)
-                raise OperationNotAllowed("Channel not included in whitelist:\n"
-                                          "  location: %s\n"
-                                          "  canonical name: %s\n"
-                                          % (bad_channel.location, bad_channel.canonical_name))
+                raise ChannelNotAllowed(Channel(url))
 
 
 LAST_CHANNEL_URLS = []
@@ -75,27 +68,31 @@ def get_index(channel_urls=(), prepend=True, platform=None,
 
 def fetch_index(channel_urls, use_cache=False, index=None):
     log.debug('channel_urls=' + repr(channel_urls))
-
-    use_cache = use_cache or context.use_index_cache
-
-    # channel_urls reversed to build up index in correct order
-    from .subdir_data import collect_all_repodata_as_index
-    index = collect_all_repodata_as_index(use_cache, channel_urls)
-
+    index = {}
+    for url in channel_urls:
+        sd = SubdirData(Channel(url))
+        index.update((rec, rec) for rec in sd.iter_records())
     return index
 
 
+def dist_str_in_index(index, dist_str):
+    match_spec = MatchSpec.from_dist_str(dist_str)
+    return any(match_spec.match(prec) for prec in itervalues(index))
+
+
 def _supplement_index_with_prefix(index, prefix):
     # supplement index with information from prefix/conda-meta
     assert prefix
-    for dist, prefix_record in iteritems(linked_data(prefix)):
-        if dist in index:
+    for prefix_record in PrefixData(prefix).iter_records():
+        if prefix_record in index:
             # The downloaded repodata takes priority, so we do not overwrite.
             # We do, however, copy the link information so that the solver (i.e. resolve)
             # knows this package is installed.
-            current_record = index[dist]
+            current_record = index[prefix_record]
             link = prefix_record.get('link') or EMPTY_LINK
-            index[dist] = PrefixRecord.from_objects(current_record, prefix_record, link=link)
+            index[prefix_record] = PrefixRecord.from_objects(
+                current_record, prefix_record, link=link
+            )
         else:
             # If the package is not in the repodata, use the local data.
             # If the channel is known but the package is not in the index, it
@@ -104,25 +101,24 @@ def _supplement_index_with_prefix(index, prefix):
             # other version of the package to this one. On the other hand, if
             # it is in a channel we don't know about, assign it a value just
             # above the priority of all known channels.
-            index[dist] = prefix_record
+            index[prefix_record] = prefix_record
 
 
 def _supplement_index_with_cache(index):
     # supplement index with packages from the cache
     for pcrec in PackageCacheData.get_all_extracted_entries():
-        dist = Dist(pcrec)
-        if dist in index:
+        if pcrec in index:
             # The downloaded repodata takes priority
-            current_record = index[dist]
-            index[dist] = PackageCacheRecord.from_objects(current_record, pcrec)
+            current_record = index[pcrec]
+            index[pcrec] = PackageCacheRecord.from_objects(current_record, pcrec)
         else:
-            index[dist] = pcrec
+            index[pcrec] = pcrec
 
 
 def _supplement_index_with_features(index, features=()):
     for feature in chain(context.track_features, features):
         rec = make_feature_record(feature)
-        index[Dist(rec)] = rec
+        index[rec] = rec
 
 
 def calculate_channel_urls(channel_urls=(), prepend=True, platform=None, use_local=False):
@@ -135,10 +131,6 @@ def calculate_channel_urls(channel_urls=(), prepend=True, platform=None, use_loc
     return all_channel_urls(channel_urls, subdirs=subdirs)
 
 
-def dist_str_in_index(index, dist_str):
-    return Dist(dist_str) in index
-
-
 def get_reduced_index(prefix, channels, subdirs, specs):
 
     # # this block of code is a "combine" step intended to filter out redundant specs
@@ -194,8 +186,14 @@ def get_reduced_index(prefix, channels, subdirs, specs):
                         pending_track_features.add(ftr_name)
 
         def push_record(record):
+            try:
+                combined_depends = record.combined_depends
+            except InvalidSpec as e:
+                log.warning("Skipping %s due to InvalidSpec: %s",
+                            record.record_id(), e._kwargs["invalid_spec"])
+                return
             push_spec(MatchSpec(record.name))
-            for _spec in record.combined_depends:
+            for _spec in combined_depends:
                 push_spec(_spec)
             if record.track_features:
                 for ftr_name in record.track_features:
@@ -226,7 +224,7 @@ def get_reduced_index(prefix, channels, subdirs, specs):
                     push_record(record)
                 records.update(new_records)
 
-        reduced_index = {Dist(rec): rec for rec in records}
+        reduced_index = {rec: rec for rec in records}
 
         if prefix is not None:
             _supplement_index_with_prefix(reduced_index, prefix)
@@ -245,6 +243,6 @@ def get_reduced_index(prefix, channels, subdirs, specs):
         known_features.update(context.track_features)
         for ftr_str in known_features:
             rec = make_feature_record(ftr_str)
-            reduced_index[Dist(rec)] = rec
+            reduced_index[rec] = rec
 
         return reduced_index
